@@ -3,15 +3,15 @@ import numpy as np
 from tqdm import tqdm
 
 
-def backproject(H, laser_grid_xyz, sensor_grid_xyz, volume_xyz,
+def backproject(H_0, laser_grid_xyz, sensor_grid_xyz, volume_xyz,
                 camera_system, t_accounts_first_and_last_bounces,
                 t_start, delta_t,
                 laser_xyz=None, sensor_xyz=None, progress=False):
     # TODO(diego): extend for multiple laser points
-    assert H.ndim == 2 and laser_grid_xyz.size == 3, \
+    assert H_0.ndim == 2 and laser_grid_xyz.size == 3, \
         'backproject only supports one laser point'
 
-    nt, ns = H.shape
+    nt, ns = H_0.shape
     assert sensor_grid_xyz.shape[0] == ns, 'H does not match with sensor_grid_xyz'
     assert (not t_accounts_first_and_last_bounces or (laser_xyz is not None and sensor_xyz is not None)), \
         't_accounts_first_and_last_bounces requires laser_xyz and sensor_xyz'
@@ -19,9 +19,9 @@ def backproject(H, laser_grid_xyz, sensor_grid_xyz, volume_xyz,
     nv, _ = volume_xyz.shape
 
     if camera_system.is_transient():
-        f = np.zeros((nt, nv), dtype=H.dtype)
+        H_1 = np.zeros((nt, nv), dtype=H_0.dtype)
     else:
-        f = np.zeros(nv, dtype=H.dtype)
+        H_1 = np.zeros(nv, dtype=H_0.dtype)
 
     # d_1: laser origin to laser illuminated point
     # d_2: laser illuminated point to x_v
@@ -50,12 +50,14 @@ def backproject(H, laser_grid_xyz, sensor_grid_xyz, volume_xyz,
             d_3 = np.linalg.norm(x_v - x_s)
             t_i = int((d_1 + d_2 + d_3 + d_4 - t_start) / delta_t)
             if camera_system.is_transient():
-                p = np.copy(H[:, s_i])
-                p[t_i+nt-1:] = 0.0
-                p[:t_i] = 0.0
-                f[:, i_v] += np.roll(p, -t_i)
+                p = np.copy(H_0[:, s_i])
+                if t_i > 0:
+                    p[:t_i] = 0.0
+                elif t_i < 0:
+                    p[t_i+nt-1:] = 0.0
+                H_1[:, i_v] += np.roll(p, -t_i)
             else:
                 if t_i >= 0 and t_i < nt:
-                    f[i_v] += H[t_i, s_i]
+                    H_1[i_v] += H_0[t_i, s_i]
 
-    return f
+    return H_1
